pub struct Tracer(/* private fields */);Expand description
A tracer for marking reachable objects
Used during the mark phase to traverse the object graph. Each thread can have its own tracer that accumulates gray objects, which are then merged back to the shared gray queue.
Implementations